==> aws-cdk.aws-kinesis-1.151.0.tar.gz: aws-cdk.aws-kinesis-1.151.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-kinesis",
    "version": "1.151.0",
    "description": "The CDK Construct Library for AWS::Kinesis",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_kinesis",
        "aws_cdk.aws_kinesis._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_kinesis._jsii": [
            "aws-kinesis@1.151.0.jsii.tgz"
        ],
        "aws_cdk.aws_kinesis": [
            "py.typed"
        ]
    },
    "python_requires": ">=3.6",
    "install_requires": [
        "aws-cdk.aws-cloudwatch==1.151.0",
        "aws-cdk.aws-iam==1.151.0",
        "aws-cdk.aws-kms==1.151.0",
        "aws-cdk.aws-logs==1.151.0",
        "aws-cdk.core==1.151.0",
        "constructs>=3.3.69, <4.0.0",
        "jsii>=1.55.1, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved",
        "Framework :: AWS CDK",
        "Framework :: AWS CDK :: 1"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)

==> aws-cdk.aws-kinesis-1.156.0.tar.gz: aws-cdk.aws-kinesis-1.156.0/setup.py <==
import json
import setuptools

kwargs = json.loads(
    """
{
    "name": "aws-cdk.aws-kinesis",
    "version": "1.156.0",
    "description": "The CDK Construct Library for AWS::Kinesis",
    "license": "Apache-2.0",
    "url": "https://github.com/aws/aws-cdk",
    "long_description_content_type": "text/markdown",
    "author": "Amazon Web Services",
    "bdist_wheel": {
        "universal": true
    },
    "project_urls": {
        "Source": "https://github.com/aws/aws-cdk.git"
    },
    "package_dir": {
        "": "src"
    },
    "packages": [
        "aws_cdk.aws_kinesis",
        "aws_cdk.aws_kinesis._jsii"
    ],
    "package_data": {
        "aws_cdk.aws_kinesis._jsii": [
            "aws-kinesis@1.156.0.jsii.tgz"
        ],
        "aws_cdk.aws_kinesis": [
            "py.typed"
        ]
    },
    "python_requires": "~=3.7",
    "install_requires": [
        "aws-cdk.aws-cloudwatch==1.156.0",
        "aws-cdk.aws-iam==1.156.0",
        "aws-cdk.aws-kms==1.156.0",
        "aws-cdk.aws-logs==1.156.0",
        "aws-cdk.core==1.156.0",
        "constructs>=3.3.69, <4.0.0",
        "jsii>=1.58.0, <2.0.0",
        "publication>=0.0.3"
    ],
    "classifiers": [
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        "Programming Language :: JavaScript",
        "Programming Language :: Python :: 3 :: Only",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Typing :: Typed",
        "Development Status :: 5 - Production/Stable",
        "License :: OSI Approved",
        "Framework :: AWS CDK",
        "Framework :: AWS CDK :: 1"
    ],
    "scripts": []
}
"""
)

with open("README.md", encoding="utf8") as fp:
    kwargs["long_description"] = fp.read()


setuptools.setup(**kwargs)
